<?php

namespace Blocksy\Extensions\WoocommerceExtra;

class BrandsImportExport {	
	public function __construct() {
		add_filter('woocommerce_product_export_column_names', [$this, 'add_columns']);
		add_filter('woocommerce_product_export_product_default_columns', [$this, 'add_columns']);
		add_filter('woocommerce_product_export_product_column_blocksy_product_brands', [$this, 'export_taxonomy'], 10, 2);

		add_filter('blocksy_export_custom_data', [$this, 'export_brands_images_data'], 10, 2);

		add_filter('woocommerce_csv_product_import_mapping_options', [$this, 'map_columns']);
		add_filter('woocommerce_csv_product_import_mapping_default_columns', [$this, 'add_columns_to_mapping_screen']);
		add_filter('woocommerce_product_import_inserted_product_object', [$this, 'set_taxonomy'], 10, 2);
	}

	public function add_columns($columns) {
		$columns['blocksy_product_brands'] = __('Blocksy Brands', 'blocksy-companion');

		return $columns;
	}

	public function export_taxonomy($value, $product) {
		$taxonomy = 'product_brands';

		$term_ids = wp_get_post_terms($product->get_id(), $taxonomy, ['fields' => 'ids']);
		$formatted_terms = [];

		if (! count($term_ids)) {
			return '';
		}

		if (! is_wp_error($term_ids)) {
			foreach ($term_ids as $term_id) {
				$formatted_term = [];
				$ancestor_ids   = array_reverse(get_ancestors($term_id, $taxonomy));

				foreach ($ancestor_ids as $ancestor_id) {
					$term = get_term($ancestor_id, $taxonomy);
					if ($term && ! is_wp_error($term)) {
						$formatted_term[] = $term->name;
					}
				}

				$term = get_term($term_id, $taxonomy);

				if ($term && ! is_wp_error($term)) {
					$formatted_term[] = $term->name;
				}

				$formatted_terms[] = implode(' > ', $formatted_term);
			}
		}

		return \Blocksy\WooImportExport::implode_values($formatted_terms);
	}

	public function export_brands_images_data($data, $product) {
		$taxonomy = 'product_brands';

		$all_terms = get_terms([
			'taxonomy' => $taxonomy,
			'hide_empty' => false,
		]);

		$formatted_terms = [];

		if (! count($all_terms)) {
			return '';
		}

		if (! is_wp_error($all_terms)) {
			foreach ($all_terms as $term) {
				$term_meta = get_term_meta(
					$term->term_id,
					'blocksy_taxonomy_meta_options'
				);

				$formatted_terms[] = [
					'name' => $term->name,
					'meta' => $term_meta
				];
			}
		}

		$data['blocksy_product_brands_images'] = $formatted_terms;

		return $data;
	}

	public function map_columns($columns) {
		$columns['blocksy_product_brands'] = __('Blocksy Brands', 'blocksy-companion');

		return $columns;
	}

	public function add_columns_to_mapping_screen($columns) {
		$columns[__('Blocksy Brands', 'blocksy-companion')] = 'blocksy_product_brands';

		return $columns;
	}

	public function set_taxonomy($product, $data) {
		if (! $product instanceof \WC_Product) {
			return $product;
		}

		if (empty($data['blocksy_product_brands'])) {
			return $product;
		}

		wp_delete_object_term_relationships($product->get_id(), 'product_brands');

		$parsed_data = \Blocksy\WooImportExport::get_import_file_data()['blocksy_product_brands_images'];
	
		$product_brands = explode(',', $data['blocksy_product_brands']);
		$terms = [];

		foreach ($product_brands as $brands) {
			if (! current_user_can('manage_product_terms')) {
				break;
			}

			$brands = trim(html_entity_decode($brands));

			if (empty($brands)) {
				continue;
			}

			if (strpos($brands, '>') !== false) {
				$brands = explode('>', $brands);
			} else {
				$brands = [$brands];
			}

			$parent = 0;

			foreach ($brands as $brand) {
				$brand = trim($brand);

				if (empty($brand)) {
					continue;
				}

				// try to find brand in $parsed_data[]['name']
				$brand_data = null;

				foreach ($parsed_data as $parsed_brand) {
					if ($parsed_brand['name'] === $brand) {
						$brand_data = $parsed_brand['meta'];
						break;
					}
				}

				$term = term_exists($brand, 'product_brands');
				$term_id = null;

				if ($term) {
					$parent = $term['term_id'];

					$terms[] = intval($term['term_id']);
				} else {
					$term = wp_insert_term($brand, 'product_brands', ['parent' => $parent]);

					if (is_wp_error($term)) {
						if ($term->get_error_code() === 'term_exists') {
							$term_id = $term->get_error_data();
						} else {
							break;
						}
					} else {
						$term_id = $term['term_id'];
						$new_meta = [];
	
						if (
							isset($brand_data[0]['image']['url'])
							&&
							! empty($brand_data[0]['image']['url'])
						) {
							$image = \Blocksy\WooImportExport::get_attachment_id_from_url($brand_data[0]['image']['url'], $product->get_id());

							if (! is_wp_error($image)) {
								$new_meta['image'] = [
									'url' => $brand_data[0]['image']['url'],
									'attachment_id' => $image
								];
							}
						}

						if (
							isset($brand_data[0]['icon_image']['url'])
							&&
							! empty($brand_data[0]['icon_image']['url'])
						) {
							$icon_image = \Blocksy\WooImportExport::get_attachment_id_from_url($brand_data[0]['icon_image']['url'], $product->get_id());

							if (! is_wp_error($icon_image)) {
								$new_meta['icon_image'] = [
									'url' => $brand_data[0]['icon_image']['url'],
									'attachment_id' => $icon_image
								];
							}
						}

						if (! empty($new_meta)) {
							update_term_meta($term_id, 'blocksy_taxonomy_meta_options', $new_meta);
						}
					}

					$parent = $term_id;
				}

				if ($term_id) {
					$terms[] = $term_id;
				}
			}
		}

		wp_set_object_terms($product->get_id(), $terms, 'product_brands');

		return $product;
	}
}
